@@ -2,6 +2,8 @@ from fusil.project_agent import ProjectAgent
 from fusil.tools import minmax
 from datetime import datetime
 
+CREATE_GRAPH_DAT = False
+
 class AggressivityAgent(ProjectAgent):
     def __init__(self, project):
         ProjectAgent.__init__(self, project, "aggressivity")
@@ -29,6 +31,9 @@ class AggressivityAgent(ProjectAgent):
         self.graph_data = None
         self.last_session_index = None
 
+        # Set default value of aggressivity
+        self.setValue(self.aggressivity_min)
+
     def setValue(self, value):
         value = round(value, 2)
         value = minmax(self.aggressivity_min, value, self.aggressivity_max)
@@ -52,7 +57,7 @@ class AggressivityAgent(ProjectAgent):
 
     def writeGraphData(self, session_index, score):
         self.last_session_index = session_index
-        if not self.graph_data:
+        if CREATE_GRAPH_DAT and not self.graph_data:
             directory = self.project().directory
             filename = directory.uniqueFilename('graph.dat')
             self.graph_data = open(filename, 'w')
@@ -64,9 +69,10 @@ class AggressivityAgent(ProjectAgent):
             score = 1.0
         else:
             score = minmax(-1.0, score, 1.0)
-        print >>self.graph_data, "%u\t%.3f\t%.3f" % (
-            self.last_session_index, score, self.aggressivity)
-        self.graph_data.flush()
+        if self.graph_data:
+            print >>self.graph_data, "%u\t%.3f\t%.3f" % (
+                self.last_session_index, score, self.aggressivity)
+            self.graph_data.flush()
 
     def on_session_done(self, score):
         self.writeGraphData(self.project().session_index, score)
