@@ -4,7 +4,7 @@ from fusil.mas.application_agent import ApplicationAgent
 from fusil.mas.mta import MTA
 from fusil.mas.univers import Univers
 from fusil.error import FUSIL_ERRORS, writeError
-from fusil.application_logger import ApplicationLogger, LOG_FILENAME
+from fusil.application_logger import ApplicationLogger
 from fusil.project import loadProject
 from fusil.process.tools import limitMemory, beNice
 from fusil.version import VERSION, LICENSE, WEBSITE
@@ -32,13 +32,13 @@ class Application(ApplicationAgent):
         parser = OptionParser(usage="%prog [options] --project=NAME [arg1 arg2 ...]")
         parser.add_option("--project", '-p', help="Project filename",
             type="str", default=None)
-        parser.add_option("--max-session", help="Maximum number of session (default: none)",
+        parser.add_option("--session", help="Maximum number of session (default: none)",
             type="int")
-        parser.add_option("--max-success", help="Maximum number of success sessions (default: 5)",
+        parser.add_option("--success", help="Maximum number of success sessions (default: 5)",
             type="int", default=5)
-        parser.add_option("--log-filename", help="Log filename (default: %s)" % LOG_FILENAME,
-            type='str', default=LOG_FILENAME)
-        parser.add_option("--keep-all-sessions", help="Do not remove session directories",
+        parser.add_option("--remove-generated-files", help="Remove a session directory even if it contains generated files",
+            action="store_true")
+        parser.add_option("--keep-sessions", help="Do not remove session directories",
             action="store_true")
         parser.add_option("--fast", help="Run faster as possible (opposite of --slow)",
             action="store_true")
@@ -47,7 +47,7 @@ class Application(ApplicationAgent):
         parser.add_option("--version", help="Display Fusil version (%s) and exit" % VERSION,
             action="store_true")
         parser.add_option("--aggressivity", help="Initial aggressivity factor in percent, value in -100.0..100.0 (default: 0.0%%)",
-            type="float", default=0.0)
+            type="float", default=None)
         parser.add_option('-v', "--verbose", help="Enable verbose mode (set log level to WARNING)",
             action="store_true")
         parser.add_option("--quiet", help="Be quiet (lowest log level), don't create log file",
@@ -105,7 +105,7 @@ class Application(ApplicationAgent):
 
         # Create univers
         if self.options.fast:
-            step_sleep = 0.005
+            step_sleep = 0.001
         elif not self.options.slow:
             step_sleep = 0.010
         else:
@@ -122,10 +122,18 @@ class Application(ApplicationAgent):
         self.univers.activate()
 
     def exit(self):
+        if self.logger.filename:
+            self.error("Fusil log written into %s" % self.logger.filename)
         self.error("Exit Fusil")
         self.mta = None
         self.univers = None
-        self.agents.clear()
+        try:
+            self.agents.clear()
+        except KeyboardInterrupt:
+            self.error("Application cleanup interrupted!")
+        except FUSIL_ERRORS, error:
+            writeError(None, error, "AGENT DEINIT ERRORT")
+            self.exitcode = 1
 
     def getInputFilename(self, description):
         arguments = self.arguments
