@@ -1,6 +1,6 @@
 from sys import stdout
 from weakref import ref as weakref_ref
-from logging import (basicConfig, getLogger, StreamHandler, Formatter,
+from logging import (getLogger, StreamHandler, Formatter,
     DEBUG, INFO, WARNING, ERROR)
 
 LOG_FILENAME = 'fusil.log'
@@ -22,36 +22,35 @@ class ApplicationLogger:
             file_level = WARNING
         else:
             stdout_level = ERROR
-            file_level = None
+            file_level = INFO
+
+        self.logger = getLogger()
 
         # fusil.log file
-        if not application.options.quiet:
-            basicConfig(level=file_level,
-                        format=self.timestamp_format,
-                        filename=application.options.log_filename,
-                        filemode='w')
-        self.logger = getLogger()
+        self.filename = LOG_FILENAME
+        self.file_handler = self.addFileHandler(self.filename, file_level)
 
         # Create stdout logger
         handler = StreamHandler(stdout)
-        handler.setLevel(stdout_level)
+        self.addHandler(handler, stdout_level)
 
-        self.logger.addHandler(handler)
-
-    def addFileHandler(self, filename, level=None):
+    def addFileHandler(self, filename, level=None, mode='w', formatter=None):
         if level is None:
             if self.application().options.verbose:
                 level = DEBUG
             else:
                 level = INFO
-        handler = StreamHandler(open(filename, 'w'))
-        handler.setFormatter(Formatter(self.timestamp_format))
+        handler = StreamHandler(open(filename, mode))
+        if not formatter:
+            formatter = Formatter(self.timestamp_format)
+        handler.setFormatter(formatter)
         self.addHandler(handler, level)
         return handler
 
     def addHandler(self, handler, level=None):
         handler.setLevel(level)
         self.logger.addHandler(handler)
+        return handler
 
     def removeFileHandler(self, handler):
         handler.stream.close()
@@ -66,11 +65,15 @@ class ApplicationLogger:
         application = self.application()
         prefix = []
         if application and application.project and application.project.session:
+            verbose = application.options.verbose
             project = application.project
+            prefix.append('[%s]' % project.nb_success)
             prefix.append('[session %s]' % project.session_index)
-            if application.options.verbose and project.step:
+            if verbose and project.step:
                 prefix.append('[step %s]' % project.step)
-        if sender is not None:
+        else:
+            verbose = False
+        if verbose and sender is not None:
             prefix.append('[%s]' % sender.name)
         if prefix:
             message = ''.join(prefix)+' '+message
