@@ -1,6 +1,6 @@
 from os.path import (basename,
     join as path_join, exists as path_exists)
-from os import mkdir, listdir
+from os import mkdir, listdir, chmod
 from shutil import rmtree
 
 class Directory:
@@ -27,10 +27,18 @@ class Directory:
         return True
 
     def rmtree(self):
-        rmtree(self.directory)
+        rmtree(self.directory, onerror=self.rmtree_error)
+
+    def rmtree_error(self, operation, argument, stack):
+        # Try to change file permission (allow write) and retry
+        try:
+            chmod(argument, 0700)
+        except OSError:
+            pass
+        operation(argument)
 
     def uniqueFilename(self, name,
-    count=None, count_format="%04d", save=True):
+    count=None, count_format="%d", save=True):
         # Test with no count suffix
         name = basename(name)
         if count is None and not self._exists(name):
