@@ -32,9 +32,13 @@ class FileWatch(ProjectAgent):
         self.start = start
         self.patterns = {}
         self.regexs = []
+        # Minimum number of lines:
+        # eg. (10, -0.2) to add -20% to score if there is fewer than 10 lines
+        self.min_nb_line = None
         self.max_nb_line = (100, 1.0)
         self.last_seed = None
         self.log_not_matching = False
+        self.show_matching = False
         self.show_not_matching = project.application().options.debug
         self.read_size = 4096
         self.cleanup_func = None
@@ -166,10 +170,10 @@ class FileWatch(ProjectAgent):
         # Search the matching pattern with the highest score
         found = None
         for pattern, score, match in self.compiled_patterns:
-            if not match(line):
-                continue
             if found and abs(score) < abs(found[1]):
                 continue
+            if not match(line):
+                continue
             found = (pattern, score)
         if not found:
             message = "Not matching line: %r" % line
@@ -180,8 +184,11 @@ class FileWatch(ProjectAgent):
             return
 
         pattern, score = found
-        func = scoreLogFunc(self, score)
-        func("Match pattern %r (score %.1f%%) in %r" % (
+        if self.show_matching:
+            log = self.error
+        else:
+            log = self.warning
+        log("Match pattern %r (score %.1f%%) in %r" % (
             pattern, score*100, line))
         self.score += score
 
@@ -213,6 +220,13 @@ class FileWatch(ProjectAgent):
             else:
                 raise
 
+    def on_session_stop(self):
+        if self.min_nb_line \
+        and (self.total_line < self.min_nb_line[0]):
+            self.error("Fewer then %s lines (total=%s): add %+.1f to the score"
+                % (self.min_nb_line[0], self.total_line, self.min_nb_line[1]*100))
+            self.score += self.min_nb_line[1]
+
     def live(self):
         # File closed: just exit
         if not self.file_obj:
