@@ -1,6 +1,6 @@
 from array import array
 from StringIO import StringIO
-from hachoir_core.bits import str2long, BIG_ENDIAN, long2raw
+from fusil.bits import str2long, BIG_ENDIAN, long2raw
 from zlib import crc32
 from logging import info
 
