@@ -7,3 +7,9 @@ class Syslog(ProjectAgent):
         self.syslog = FileWatch(project, open('/var/log/syslog'), 'syslog:syslog', start='end')
         self.messages = FileWatch(project, open('/var/log/messages'), 'syslog:messages', start='end')
 
+    def __iter__(self):
+        if self.syslog:
+            yield self.syslog
+        if self.messages:
+            yield self.messages
+
