@@ -1,36 +1,8 @@
 from fusil.mangle_agent import MangleAgent
 from random import randint, choice
+from fusil.mangle_op import SPECIAL_VALUES
 from array import array
 
-def generateSpecialValues():
-    values = (
-        # Special values in big endian
-        # SPECIAL_VALUES will contains value in big endian and little endian
-        "\x00",
-        "\x00\x00",
-        "\x7f",
-        "\x7f\xff",
-        "\x7f\xff\xff\xff",
-        "\x80",
-        "\x80\x00",
-        "\x80\x00\x00\x00",
-        "\xfe",
-        "\xfe\xff",
-        "\xfe\xff\xff\xff",
-        "\xff",
-        "\xff\xff",
-        "\xff\xff\xff\xff",
-    )
-    result = []
-    for item in values:
-        result.append(item)
-        itemb = item[::-1]
-        if item != itemb:
-            result.append(itemb)
-    return result
-
-SPECIAL_VALUES = generateSpecialValues()
-
 class MangleConfig:
     def __init__(self, min_op=1, max_op=100, operations=None):
         """
