@@ -1,3 +1,6 @@
+from fusil.error import FUSIL_ERRORS, writeError
+from logging import getLogger
+
 class AgentList:
     def __init__(self):
         self.agents = []
@@ -8,9 +11,12 @@ class AgentList:
         self.agents.append(agent)
 
     def _destroy(self, agent):
-        agent.debug("Removed from agent list")
-        agent.deactivate()
-        agent.unregister(False)
+        try:
+            agent.debug("Removed from agent list")
+            agent.deactivate()
+            agent.unregister(False)
+        except FUSIL_ERRORS, error:
+            writeError(getLogger(), error, "AGENT DEINIT ERROR")
 
     def remove(self, agent, destroy=True):
         if agent not in self.agents:
