@@ -4,14 +4,27 @@ class Mailbox:
     def __init__(self, agent, mta):
         self.messages = []
         self.agent = weakref_ref(agent)
-        for event in agent.getEvents():
+        self.mta = weakref_ref(mta)
+        self.events = agent.getEvents()
+        for event in self.events:
             mta.registerMailingList(self, event)
 
+    def unregister(self):
+        mta = self.mta()
+        if not mta:
+            return
+        for event in self.events:
+            mta.unregisterMailingList(self, event)
+
     def clear(self):
         self.messages = []
 
     def deliver(self, message):
-        if not self.agent().is_active:
+        agent = self.agent()
+        if not agent:
+            self.unregister()
+            return
+        if not agent.is_active:
             return
         self.messages.append(message)
 
