@@ -11,15 +11,17 @@ class MTA(ApplicationAgent):
         ApplicationAgent.__init__(self, "mta", application, None)
         self.setupMTA(self, application.logger)
         self.mailing_list = {}
-        self.messages = []
+        self.queue = []
+        self.queue_events = set()
 
     def hasMessage(self):
-        return bool(self.messages)
+        return bool(self.queue)
 
     def clear(self):
-        if self.messages:
-            self.debug("Remove %s messages" % len(self.messages))
-        self.messages = []
+        if self.queue:
+            self.debug("Remove %s messages" % len(self.queue))
+        self.queue = []
+        self.queue_events = set()
 
     def registerMailingList(self, mailbox, event):
         mailbox_ref = weakref_ref(mailbox)
@@ -36,11 +38,15 @@ class MTA(ApplicationAgent):
         self.mailing_list[event].remove(mailbox)
 
     def deliver(self, message):
-        self.messages.append(message)
+        if message.event in self.queue_events:
+            self.info("Drop duplicate message: %s" % message)
+            return
+        self.queue.append(message)
+        self.queue_events.add(message.event)
 
     def live(self):
         # Delive messages to agents including myself
-        for message in self.messages:
+        for message in self.queue:
             if message.event not in self.mailing_list:
                 self.debug("No subscriber to event %s" % message.event)
                 continue
@@ -56,5 +62,5 @@ class MTA(ApplicationAgent):
             # Remove broken references
             for mailbox_ref in broken_refs:
                 mailing_list.remove(mailbox_ref)
-        self.messages = []
+        self.clear()
 
