@@ -1,11 +1,11 @@
 from fusil.project_agent import ProjectAgent
 from ptrace.linux_proc import ProcError, readProcessStatm, searchProcessByName
 from fusil.process.tools import dumpProcessInfo
-from os import stat
-from errno import ENOENT
+from os import stat, kill
 from ptrace.os_tools import RUNNING_LINUX
 if RUNNING_LINUX:
     from fusil.process.cpu_probe import CpuProbe
+from errno import ESRCH, ENOENT
 
 class AttachProcess(ProjectAgent):
     def __init__(self, project, process_name):
@@ -45,16 +45,23 @@ class AttachProcess(ProjectAgent):
                 return
 
     def checkAlive(self):
-        try:
-            stat('/proc/%s' % self.pid)
-            return True
-        except OSError, err:
-            if err.errno == ENOENT:
-                self.error("Process %s disappeared" % self.pid)
-                self.stop(self.death_score)
-                return False
-            else:
-                raise
+        if RUNNING_LINUX:
+            try:
+                stat('/proc/%s' % self.pid)
+                return True
+            except OSError, err:
+                if err.errno != ENOENT:
+                    raise
+        else:
+            try:
+                kill(self.pid, 0)
+                return True
+            except OSError, err:
+                if err.errno != ESRCH:
+                    raise
+        self.error("Process %s disappeared" % self.pid)
+        self.stop(self.death_score)
+        return False
 
     def checkMemory(self):
         try:
