@@ -24,7 +24,7 @@ else:
         kill(process.pid, SIGKILL)
 
 class CreateProcess(ProjectAgent):
-    def __init__(self, project, arguments=None, stdout="file", timeout=10.0, name=None):
+    def __init__(self, project, arguments=None, stdout="file", stdin=None, timeout=10.0, name=None):
         if not name:
             name = "process:%s" % basename(arguments[0])
         ProjectAgent.__init__(self, project, name)
@@ -38,6 +38,11 @@ class CreateProcess(ProjectAgent):
         self.popen_args = {
             'stderr': STDOUT,
         }
+        if stdin is not None:
+            if stdin == "null":
+                self.popen_args['stdin'] = open('/dev/null', 'r')
+            else:
+                raise ValueError("Invalid stdin value: %r" % stdin)
 
     def init(self):
         self.process = None
@@ -62,7 +67,10 @@ class CreateProcess(ProjectAgent):
         for index, argument in enumerate(arguments):
             if "\0" in argument:
                 raise ValueError("Argument %s contains nul byte: %r" % (index, argument))
-        arguments[0] = locateProgram(arguments[0])
+        program = locateProgram(arguments[0], use_none=True)
+        if not program:
+            raise ValueError("Unable to find the program %r in PATH" % arguments[0])
+        arguments[0] = program
         popen_args = self.createPopenArguments()
         self.warning("Create process %r" % ' '.join(arguments))
         try:
