@@ -130,11 +130,10 @@ class Environment(ProjectAgent):
         # Generate new variables
         for var in self.variables:
             for name, value in var.create():
-                if not RUNNING_WINDOWS and name == "MALLOC_CHECK_" and value == '2':
-                    log_func = self.info
-                else:
-                    log_func = self.warning
-                log_func("Create %s (len=%s)" % (name, len(value)))
+                message = "Create %s (len=%s)" % (name, len(value))
+                if len(value) <= 50:
+                    message += ": %r" % value
+                self.warning(message)
                 if "\0" in value:
                     raise ValueError("Nul byte in environment variable value is forbidden!")
                 env[name] = value
