@@ -23,11 +23,23 @@ if RUNNING_WINDOWS:
         handle = OpenProcess(PROCESS_ALL_ACCESS, True, pid)
         SetPriorityClass(handle, value)
 else:
-    from resource import setrlimit, RLIMIT_AS
-    from os import nice
+    from resource import getrlimit, setrlimit, RLIMIT_AS
+    try:
+        from os import nice
+    except ImportError, err:
+        # Workaround PyPy lack: it doesn't have os.nice()
+        print "WARNING: Missing function os.nice()"
+        def nice(level):
+            pass
 
-    def limitMemory(nbytes):
-        setrlimit(RLIMIT_AS, (nbytes, -1))
+    def limitMemory(soft):
+        try:
+            old_soft, hard = getrlimit(RLIMIT_AS)
+            if old_soft != -1:
+                soft = min(soft, old_soft)
+        except ValueError:
+            hard = -1
+        setrlimit(RLIMIT_AS, (soft, hard))
 
     def beNice(very_nice=False):
         if very_nice:
@@ -54,16 +66,19 @@ def system(logger, command):
     raise RuntimeError("Unable to run command %r (error %r)" % (
         command, exit_code))
 
-def locateProgram(program):
-    # FIXME: Fix for Windows
+def locateProgram(program, use_none=False):
     if program[0] == '/':
         return program
+    if use_none:
+        default = None
+    else:
+        default = program
     path = getenv('PATH')
     if not path:
-        return program
+        return default
     for dirname in path.split(":"):
         filename = path_join(dirname, program)
         if access(filename, X_OK):
             return filename
-    return program
+    return default
 
