@@ -6,7 +6,11 @@ from fusil.mas.agent_list import AgentList
 from fusil.project_directory import ProjectDirectory
 from time import time
 from fusil.aggressivity import AggressivityAgent
-from ptrace.os_tools import RUNNING_LINUX
+from ptrace.os_tools import RUNNING_LINUX, RUNNING_PYPY
+from os import unlink
+from shutil import copyfile
+if RUNNING_PYPY:
+    from gc import collect as gc_collect
 if RUNNING_LINUX:
     from fusil.system_calm import SystemCalm
 
@@ -27,10 +31,10 @@ class Project(ProjectAgent):
             self.system_calm = None
 
         # Configuration
-        self.max_session = application.options.max_session
+        self.max_session = application.options.session
         self.success_score = 0.50 # minimum score for a successful session
         self.error_score = -0.50 # maximum score for a session failure
-        self.max_success = application.options.max_success
+        self.max_success = application.options.success
 
         # Session
         self.session = None
@@ -51,8 +55,9 @@ class Project(ProjectAgent):
         self.aggressivity = AggressivityAgent(self)
 
         # Initial aggresssivity value
-        self.aggressivity.setValue(application.options.aggressivity / 100)
-        self.warning("Initial aggressivity: %s" % self.aggressivity)
+        if application.options.aggressivity is not None:
+            self.aggressivity.setValue(application.options.aggressivity / 100)
+            self.error("Initial aggressivity: %s" % self.aggressivity)
 
     def registerAgent(self, agent):
         self.debug("Register %r" % agent)
@@ -69,11 +74,28 @@ class Project(ProjectAgent):
         self.directory.activate()
         self.error("Use directory: %s" % self.directory.directory)
 
+        self.initLog()
+
         self.project_start = time()
         self.step = None
         self.nb_success = 0
         self.createSession()
 
+    def initLog(self):
+        # Move fusil.log into run-xxx/project.log: copy fusil.log content
+        # and then remove fusil.log file and log handler)
+        logger = self.application().logger
+        filename = self.directory.uniqueFilename("project.log")
+        if logger.file_handler:
+            copyfile(logger.filename, filename)
+            self.log_handler = logger.addFileHandler(filename, mode='a')
+            logger.removeFileHandler(logger.file_handler)
+            unlink(logger.filename)
+            logger.file_handler = None
+        else:
+            self.log_handler = logger.addFileHandler(filename)
+        logger.filename = filename
+
     def deinit(self):
         self.summarize()
         self.aggressivity = None
@@ -82,6 +104,16 @@ class Project(ProjectAgent):
             self.agents.remove(agent, False)
         self.agents.clear()
 
+        remove = self.directory.destroy()
+        if remove:
+            logger = self.application().logger
+            logger.removeFileHandler(self.log_handler)
+            logger.filename = None
+
+        self.directory = None
+        if RUNNING_PYPY:
+            gc_collect()
+
     def createSession(self):
         # Wait until system is calm
         if self.system_calm:
@@ -90,6 +122,7 @@ class Project(ProjectAgent):
         self.info("Create session")
         self.step = 0
         self.session_index += 1
+        self.use_timeout = bool(self.session_timeout)
         self.session_start = time()
 
         # Enable project agents
@@ -161,12 +194,13 @@ class Project(ProjectAgent):
             self.nb_success += 1
             self.error("Success %s/%s!" % (self.nb_success, self.max_success))
             if self.max_success <= self.nb_success:
+                self.error("Stop! Limited to %s successes, use --success option for more" % self.max_success)
                 self.send('univers_stop')
                 return
 
         # Hit maximum number of session?
         if self.max_session and self.max_session <= self.session_index:
-            self.error("Stop (limited to %s session)" % self.max_session)
+            self.error("Stop! Limited to %s sessions, use --session option for more" % self.max_session)
             self.send('univers_stop')
             return
 
@@ -178,12 +212,13 @@ class Project(ProjectAgent):
             self.step += 1
         if not self.session:
             return
-        if not self.session_timeout:
+        if not self.use_timeout:
             return
         duration = time() - self.session_start
         if self.session_timeout <= duration:
-            self.error("Timeout!")
+            self.error("Project session timeout!")
             self.send('session_stop')
+            self.use_timeout = False
 
     def summarize(self):
         count = self.session_executed
