@@ -8,16 +8,18 @@ class ProjectAgent(Agent):
             mta = project.mta()
         Agent.__init__(self, name, mta)
         self.project = weakref_ref(project)
-        if project is self:
-            return
-        self.score_weight = 1.0
-        self.register()
+        if project is not self:
+            self.score_weight = 1.0
+            self.register()
 
     def register(self):
         self.project().registerAgent(self)
 
     def unregister(self, destroy=True):
-        self.project().unregisterAgent(self, destroy)
+        project = self.project()
+        if not project:
+            return
+        project.unregisterAgent(self, destroy)
 
     def scoreLogFunc(self):
         score = self.getScore()
