@@ -15,9 +15,14 @@ class ProjectDirectory(ProjectAgent, Directory):
         self.mkdir()
 
     def destroy(self):
-        if self.isEmpty(True):
+        if not self.directory:
+            return False
+        remove = self.isEmpty(True)
+        if remove:
             self.info("Remove directory: %s" % self.directory)
             self.rmtree()
         else:
             self.error("Keep non-empty directory: %s" % self.directory)
+        self.directory = None
+        return remove
 
