@@ -3,6 +3,26 @@ from fusil.session_agent import SessionAgent
 from fusil.mas.agent_list import AgentList
 from fusil.session_directory import SessionDirectory
 from fusil.score import normalizeScore
+from logging import INFO
+from ptrace.os_tools import RUNNING_PYPY
+from logging import Formatter
+if RUNNING_PYPY:
+    from gc import collect as gc_collect
+
+class SessionFormatter(Formatter):
+    """
+    Log formatter for session.log: only write the message and
+    remove fusil prefix:
+
+    "[0][session 0010] text" => "text"
+    """
+    def format(self, record):
+        text = record.getMessage()
+        try:
+            text = text.split("] ", 1)[1]
+        except IndexError:
+            pass
+        return text
 
 class Session(SessionAgent):
     def __init__(self, project):
@@ -56,7 +76,8 @@ class Session(SessionAgent):
         self.directory = SessionDirectory(self, directory)
 
         log_filename = self.directory.uniqueFilename("session.log")
-        self.log_handler = self.logger.addFileHandler(log_filename)
+        self.log_handler = self.logger.addFileHandler(
+            log_filename, level=INFO, formatter=SessionFormatter())
 
         self.stopped = False
 
@@ -68,6 +89,8 @@ class Session(SessionAgent):
             self.logger.removeFileHandler(self.log_handler)
         self.debug("Remove all session agents")
         self.agents.clear()
+        if RUNNING_PYPY:
+            gc_collect()
 
     def live(self):
         if self.stopped:
