@@ -16,24 +16,25 @@ class SessionDirectory(SessionAgent, Directory):
 
     def keepDirectory(self):
         session = self.session()
+        application = session.project().application()
         if not self.isEmpty(False):
             if session.isSuccess():
                 # Session sucess and non-empty directory: keep directory
                 self.warning("Success: keep directory %s" % self.directory)
                 return True
 
-            application = session.project().application()
             if application.exitcode:
                 # Session sucess and non-empty directory: keep directory
                 self.warning("Fusil error: keep directory %s" % self.directory)
                 return True
 
-            if application.options.keep_all_sessions:
+            if application.options.keep_sessions:
                 # User asked to keep all datas
                 self.warning("Keep directory %s" % self.directory)
                 return True
 
-        if not self.isEmpty(True):
+        if not application.options.remove_generated_files \
+        and not self.isEmpty(True):
             # Project generated some extra files: keep the directory
             self.warning("Keep non-empty directory %s" % self.directory)
             return True
