@@ -7,8 +7,8 @@ if [ "x$DATA" = "x" ]; then
     exit 1
 fi
 
-if [ ! -e "$DATA" ]; then
-    echo "Unable to read input data: $DATA"
+if [ ! -f "$DATA" ]; then
+    echo "File $DATA doesn't exit"
     exit 1
 fi
 
