@@ -5,7 +5,7 @@ Project based on "sysfuzz.c" fuzzer by Digital Dwarf Society
    http://www.digitaldwarf.be/
 """
 
-from fusil.c_tools import FuzzyFunctionC, CodeC, MIN_INT32, MAX_INT32
+from fusil.c_tools import FuzzyFunctionC, CodeC
 from fusil.process.create import CreateProcess
 from fusil.process.watch import WatchProcess
 from random import choice, randint
