@@ -3,11 +3,25 @@ Generate PHP source code using random functions with random arguments.
 Use "php" command line program.
 """
 
+VARIABLES = 'abcde'
+
 def setupProject(project):
     DEBUG_PROJECT = True
 
     php = PhpSource(project)
+    # Don't kill any process!
     php.ignore_functions.add('posix_kill')
+    # Avoid timeout
+    php.ignore_functions.add('ftp_connect')
+    php.ignore_functions.add('mysql_connect')
+    php.ignore_functions.add('mysql_pconnect')
+    php.ignore_functions.add('dns_get_mx')
+    php.ignore_functions.add('getmxrr')
+    php.ignore_functions.add('dns_check_record')
+    php.ignore_functions.add('pfsockopen')
+    php.ignore_functions.add('dns_get_record')
+    php.ignore_functions.add('gethostbynamel')
+    php.ignore_functions.add('ftp_ssl_connect')
 
     process = PhpProcess(project, ['php', '<source.php>'], timeout=10.0)
     watch = WatchProcess(process, exitcode_score=0.10)
@@ -36,7 +50,7 @@ from fusil.process.create import CreateProcess
 from fusil.process.watch import WatchProcess
 from fusil.process.stdout import WatchStdout
 from fusil.project_agent import ProjectAgent
-from fusil.bytes_generator import BytesGenerator, IntegerGenerator
+from fusil.bytes_generator import BytesGenerator
 from base64 import b64encode
 from random import choice, randint
 from weakref import ref
@@ -81,16 +95,21 @@ class NullGenerator:
 
 class ReferenceGenerator:
     def createValue(self):
-        return "&$%s" % choice('abcd')
+        return "&$%s" % choice(VARIABLES)
+
+class VariableGenerator:
+    def createValue(self):
+        return "$%s" % choice(VARIABLES)
 
 class PhpSource(ProjectAgent):
     def __init__(self, project):
         ProjectAgent.__init__(self, project, "php_source")
         self.generators = [
             Base64Generator(10),
-#            LengthGenerator(),
+            LengthGenerator(),
             NullGenerator(),
             ReferenceGenerator(),
+            VariableGenerator(),
         ]
         self.min_arguments = 0
         self.max_arguments = 10
@@ -139,6 +158,7 @@ class PhpSource(ProjectAgent):
             "$b = Array('hello', 10, 3);",
             "$c = 'Hello World!';",
             "$d = null;",
+            "$e = 3.14;",
             '',
         ]
         nb_instr = randint(self.min_instr, self.max_instr)
