@@ -33,6 +33,7 @@ def main():
     # Test documentation in doc/*.rst files
     testDoc('doc/c_tools.rst')
     testDoc('doc/file_watch.rst')
+    testDoc('doc/mangle.rst')
 
     # Unit tests as reST
     testDoc('tests/file_watch_read.rst')
@@ -40,6 +41,7 @@ def main():
 
     # Test documentation of some functions/classes
     testModule("fusil.tools")
+    testModule("fusil.fuzzer.python")
 
 if __name__ == "__main__":
     main()
